@@ -85,7 +85,7 @@ class GSPeerConnectionBroadcaster:
                     description = ast.literal_eval(description)
                 desc = type('new_dict', (object,), description)
 
-                self._logger.info(str(description["sdp"]))
+
                 offer = RTCSessionDescription(sdp=description["sdp"], type=description["type"])
 
                 self._logger.info(str(self.rtconfiList))
@@ -126,6 +126,10 @@ class GSPeerConnectionBroadcaster:
                                                    {"type": pc.localDescription.type,
                                                     "sdp": pc.localDescription.sdp})})
 
+            @self.sio.event
+            async def joined():
+                await self.sio.emit("broadcaster")
+
             @self.sio.event
             async def disconnectPeer(id):
                 if id in self.peerConnections:
